@@ -195,3 +195,50 @@ if __name__ == "__main__":
     STUDENT_GRADE_FILE = "/home/tuhe/Documents/unitgrade_private_v1/examples/example_simplest/students/programs/report1_grade.py"
 
     output_tar = deploy_assignment("hello4", INSTRUCTOR_BASE, INSTRUCTOR_GRADE_FILE, STUDENT_BASE, STUDENT_GRADE_FILE=STUDENT_GRADE_FILE)
+
+
+def format_autolab_json(data):
+    import json
+
+    stages = []
+    pres = {
+        "_presentation": "semantic",
+        "stages": [], # "Build", "Test", "Timing"],
+    }
+    for n, qs in data['details'].items():
+        print(n)
+        title = qs['title']
+        rs = {}
+        for item, val in qs['items'].items():
+            print(item, val)
+            item_name = item[1]
+            rs[item_name] = {'passed': val['status'] == 'pass'}
+        rs['Total'] = qs['obtained']
+        stages.append(title)
+        pres[title] = rs
+    pres['stages'] = stages
+
+    # rs = {
+    #     "_presentation": "semantic",
+    #     "stages": ["Build", "Test", "Timing"],
+    #     "Test": {
+    #         "Add Things": {
+    #             "passed": True
+    #         },
+    #         "Return Values": {
+    #             "passed": False,
+    #             "hint": "You need to return 1"
+    #         }
+    #     },
+    #     'scores': 234,
+    #       'pass': True
+    # }
+    # s = json.dumps(pres, indent=2)
+    s = json.dumps(pres)
+    print(s)
+    scores = {"scores": {"Total": data['total'][0], 'Possible': data['total'][1]}}
+    print( json.dumps(scores) )
+
+
+    a = 234
+    pass
\ No newline at end of file
